import React, { useState } from 'react';
import replaceHighlitingWord from '../utils/replaceHighlitingWord';
import { useEffect } from 'react';
import { IDictionary } from '../type';

interface IProps {
  dictionary: IDictionary[];
  children: string;
}
function Highlighter({ dictionary, children }: IProps) {
  const [clickedWord, setClickedWord] = useState('');

  const onClickHandler = (event: React.MouseEvent<HTMLDivElement, MouseEvent>) => {
    const target = event.target as HTMLDivElement;

    if (target.tagName === 'SPAN') {
      const nextWord = clickedWord === target.innerHTML ? '' : target.innerHTML;
      setClickedWord(nextWord);
    }
  };
  const closeDictionary = () => {
    setClickedWord('');
  };

  const innerHTML = replaceHighlitingWord({
    children,
    dictionary,
    clickedWord,
  });

  useEffect(() => {
    if (!document.querySelector('.close')) return;
    document.querySelector('.close')?.addEventListener('click', closeDictionary);
  }, [clickedWord]);

  return (
    <>
      <div dangerouslySetInnerHTML={{ __html: innerHTML }} onClick={onClickHandler}></div>
    </>
  );
}

export default Highlighter;
